Learn R Programming

rdaisi (version 0.1.3)

configure_daisi: Set the necessary environment variables to configure the Daisi client

Description

Set the necessary environment variables to configure the Daisi client

Usage

configure_daisi(python_path = NULL, daisi_instance = "app")

Value

TRUE if successful update has occurred

Arguments

python_path

The path to the python binary on your system

daisi_instance

The Daisi instance to connect to

Examples

Run this code
if (FALSE) {
configure_daisi(python_path = "/usr/local/bin/python3", daisi_instance = "app")
}

Run the code above in your browser using DataLab