powered by
Set the necessary environment variables to configure the Daisi client
configure_daisi(python_path = NULL, daisi_instance = "app")
TRUE if successful update has occurred
The path to the python binary on your system
The Daisi instance to connect to
if (FALSE) { configure_daisi(python_path = "/usr/local/bin/python3", daisi_instance = "app") }
Run the code above in your browser using DataLab